Type Alias Size2D
pub type Size2D<T> = Size2D<T, UnknownUnit>;Available on crate feature
canvas only.Aliased Type
pub struct Size2D<T> {
pub width: T,
pub height: T,
}Fields
width: TThe extent of the element in the U units along the x axis (usually horizontal).
height: TThe extent of the element in the U units along the y axis (usually vertical).